@@ -438,6 +438,24 @@ YAZ_EXPORT void yaz_opac_decode_wrbuf(yaz_marc_t mt, Z_OPACRecord *r,
 YAZ_EXPORT void yaz_opac_decode_wrbuf2(yaz_marc_t mt, Z_OPACRecord *r,
                                        WRBUF wrbuf, yaz_iconv_t cd);
 
+#if YAZ_HAVE_XML2
+/** \brief Converts XML to OPAC
+    \param mt marc handle
+    \param buf_in XML buffer
+    \param size_in size of XML buffer
+    \param dst Z39.50 OPAC result - allocated by NMEM on marc handle
+    \param cd iconv handle for the OPAC content (not ISO2709 part)
+    \param nmem memory for OPACRecord (if NULL, mt NMEM memory is used)
+    \param syntax OID for embedded MARC (if NULL, USMARC is used)
+    \retval 1 conversion OK
+    \retval 0 conversion NOT OK
+    \*/
+YAZ_EXPORT int yaz_xml_to_opac(yaz_marc_t mt,
+                               const char *buf_in, size_t size_in,
+                               Z_OPACRecord **dst, yaz_iconv_t cd,
+                               NMEM nmem, const Odr_oid *syntax);
+#endif
+
 /** \brief flushes records
     \param mt handle
     \param wr WRBUF for output
