@@ -238,7 +238,7 @@ COMSTACK tcpip_type(int s, int flags, int protocol, void *vp)
     sp->connect_response_len = 0;
 
     p->timeout = COMSTACK_DEFAULT_TIMEOUT;
-    TRC(fprintf(stderr, "Created new TCPIP comstack\n"));
+    TRC(fprintf(stderr, "Created new TCPIP comstack h=%p\n", p));
 
     return p;
 }
@@ -367,7 +367,7 @@ struct addrinfo *tcpip_getaddrinfo(const char *str, const char *port,
     if (!strcmp("@", host))
     {
         hints.ai_flags = AI_PASSIVE;
-        hints.ai_family = AF_INET6;
+        hints.ai_family = AF_UNSPEC;
         error = getaddrinfo(0, port, &hints, &res);
         *ipv6_only = 0;
     }
@@ -463,15 +463,27 @@ void *tcpip_straddr(COMSTACK h, const char *str)
         int s = -1;
         for (ai = sp->ai; ai; ai = ai->ai_next)
         {
-            s = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
-            if (s != -1)
-                break;
+            if (ai->ai_family == AF_INET6)
+            {
+                s = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
+                if (s != -1)
+                    break;
+            }
+        }
+        if (s == -1)
+        {
+            for (ai = sp->ai; ai; ai = ai->ai_next)
+            {
+                s = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
+                if (s != -1)
+                     break;
+            }
         }
         if (s == -1)
             return 0;
         assert(ai);
         h->iofile = s;
-        if (ipv6_only >= 0 &&
+        if (ai->ai_family == AF_INET6 && ipv6_only >= 0 &&
             setsockopt(h->iofile,
                        IPPROTO_IPV6,
                        IPV6_V6ONLY, &ipv6_only, sizeof(ipv6_only)))
@@ -534,7 +546,7 @@ int tcpip_connect(COMSTACK h, void *address)
     struct sockaddr_in *add = (struct sockaddr_in *) address;
 #endif
     int r;
-    TRC(fprintf(stderr, "tcpip_connect\n"));
+    TRC(fprintf(stderr, "tcpip_connect h=%p\n", h));
     h->io_pending = 0;
     if (h->state != CS_ST_UNBND)
     {
@@ -1025,7 +1037,7 @@ int tcpip_get(COMSTACK h, char **buf, int *bufsize)
     int tmpi, berlen, rest, req, tomove;
     int hasread = 0, res;
 
-    TRC(fprintf(stderr, "tcpip_get: bufsize=%d\n", *bufsize));
+    TRC(fprintf(stderr, "tcpip_get: h=%p bufsize=%d\n", h, *bufsize));
     if (sp->altlen) /* switch buffers */
     {
         TRC(fprintf(stderr, "  %d bytes in altbuf (%p)\n", sp->altlen,
@@ -1243,7 +1255,7 @@ int tcpip_put(COMSTACK h, char *buf, int size)
     int res;
     struct tcpip_state *state = (struct tcpip_state *)h->cprivate;
 
-    TRC(fprintf(stderr, "tcpip_put: size=%d\n", size));
+    TRC(fprintf(stderr, "tcpip_put: h=%p size=%d\n", h, size));
     h->io_pending = 0;
     h->event = CS_DATA;
     if (state->towrite < 0)
@@ -1361,7 +1373,7 @@ void tcpip_close(COMSTACK h)
 {
     tcpip_state *sp = (struct tcpip_state *)h->cprivate;
 
-    TRC(fprintf(stderr, "tcpip_close h=%p pid=%d\n", h, getpid()));
+    TRC(fprintf(stderr, "tcpip_close: h=%p pid=%d\n", h, getpid()));
     if (h->iofile != -1)
     {
 #if HAVE_GNUTLS_H
